Welcome to elephant_parsel's documentation!
===========================================

PostgresDB
----------

.. autoclass:: elephant_parsel.postgres_db.PostgresDB
    :members:
    :undoc-members:
    :special-members: __init__


.. autoclass:: elephant_parsel.postgres_db.PostgresTransaction
    :members:
    :undoc-members:

.. autoclass:: elephant_parsel.postgres_db.PostgresDBException
    :members:

